==> igniteui-angular-charts-16.0.0.tgz: package/esm2015/lib/RateOfChangeAndMomentumIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RateOfChangeAndMomentumIndicatorStrategy } from "./RateOfChangeAndMomentumIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let RateOfChangeAndMomentumIndicator = /*@__PURE__*/ (() => {
    class RateOfChangeAndMomentumIndicator extends StrategyBasedIndicator {
        get_ul() {
            return new RateOfChangeAndMomentumIndicatorStrategy();
        }
        get ul() {
            return this.get_ul();
        }
        get_uy() {
            return RateOfChangeAndMomentumIndicator.$;
        }
        get uy() {
            return this.get_uy();
        }
        get u6() {
            return typeGetValue(this.c(RateOfChangeAndMomentumIndicator.u7));
        }
        set u6(a) {
            this.h(RateOfChangeAndMomentumIndicator.u7, a);
        }
        ur() {
            return this.u6;
        }
        u0(a) {
            this.u6 = a;
        }
    }
    RateOfChangeAndMomentumIndicator.$t = markType(RateOfChangeAndMomentumIndicator, 'RateOfChangeAndMomentumIndicator', StrategyBasedIndicator.$);
    RateOfChangeAndMomentumIndicator.u7 = StrategyBasedIndicator.u3(14, RateOfChangeAndMomentumIndicator.$);
    return RateOfChangeAndMomentumIndicator;
})();

==> igniteui-angular-charts-17.2.1.tgz: package/esm2015/lib/RateOfChangeAndMomentumIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RateOfChangeAndMomentumIndicatorStrategy } from "./RateOfChangeAndMomentumIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let RateOfChangeAndMomentumIndicator = /*@__PURE__*/ (() => {
    class RateOfChangeAndMomentumIndicator extends StrategyBasedIndicator {
        bg() {
            return new RateOfChangeAndMomentumIndicator();
        }
        get_yz() {
            return new RateOfChangeAndMomentumIndicatorStrategy();
        }
        get yz() {
            return this.get_yz();
        }
        get_zc() {
            return RateOfChangeAndMomentumIndicator.$;
        }
        get zc() {
            return this.get_zc();
        }
        get zk() {
            return typeGetValue(this.c(RateOfChangeAndMomentumIndicator.zl));
        }
        set zk(a) {
            this.h(RateOfChangeAndMomentumIndicator.zl, a);
        }
        y5() {
            return this.zk;
        }
        ze(a) {
            this.zk = a;
        }
    }
    RateOfChangeAndMomentumIndicator.$t = markType(RateOfChangeAndMomentumIndicator, 'RateOfChangeAndMomentumIndicator', StrategyBasedIndicator.$);
    RateOfChangeAndMomentumIndicator.zl = StrategyBasedIndicator.zh(14, RateOfChangeAndMomentumIndicator.$);
    return RateOfChangeAndMomentumIndicator;
})();
